@@ -47,6 +47,22 @@ class DInfo
     private $_isPrintingLinkedTbl;
     private $_allActions;
 
+    private static $_instance;
+
+	public static function singleton()
+	{
+		if (!isset(self::$_instance)) {
+			self::$_instance = new self();
+		}
+
+		return self::$_instance;
+	}
+
+    private function __construct()
+    {
+
+    }
+
     public function ShowDebugInfo()
     {
         return "DINFO: conftype={$this->_confType} view={$this->_view} viewname={$this->_viewName} mid={$this->_mid} pid={$this->_pid} tid={$this->_tid} ref={$this->_ref} act={$this->_act}\n";
@@ -415,10 +431,12 @@ class DInfo
         if (substr($loc, 0, 13) == 'extprocessor:') {
             $type = substr($loc, 13);
             if ($type == '$$type') {
-                if ($node != null)
+                if ($node != null) {
                     $type = $node->GetChildVal('type');
-                else
+                }
+                if ($type == null) { // default
                     $type = 'fcgi';
+                }
             }
             if ($type == 'cgi') {
                 $o['cgi'] = 'CGI Daemon';
