@@ -7,26 +7,31 @@
 * Please Note: These language files will be overwritten during software updates.
 *
 * @author     LiteSpeed Technoglogies
-* @copyright  Copyright (c) LiteSpeed 2014-2019
+* @copyright  Copyright (c) LiteSpeed 2014-2020
 * @link       https://www.litespeedtech.com/
 */
 
 global $_gmsg;
 
+$_gmsg['menu_cloudimage'] = 'Cloud Images';
 $_gmsg['menu_cluster'] = 'Clusters';
 $_gmsg['menu_community'] = 'Community';
 $_gmsg['menu_compilephp'] = 'Compile PHP';
 $_gmsg['menu_dashboard'] = 'Dashboard';
+$_gmsg['menu_devgroup'] = 'Developer Mailing List';
 $_gmsg['menu_docs'] = 'Documentation';
+$_gmsg['menu_forum'] = 'Forum';
 $_gmsg['menu_general'] = 'General';
 $_gmsg['menu_guides'] = 'Guides';
 $_gmsg['menu_help'] = 'Help';
 $_gmsg['menu_logviewer'] = 'Server Log Viewer';
+$_gmsg['menu_releaselog'] = 'Release Log';
 $_gmsg['menu_restart'] = 'Graceful Restart';
 $_gmsg['menu_rtstats'] = 'Real-Time Stats';
 $_gmsg['menu_serv'] = 'Server Configuration';
 $_gmsg['menu_sl'] = 'Listeners';
 $_gmsg['menu_sl_'] = 'Listener';
+$_gmsg['menu_slack'] = 'Slack';
 $_gmsg['menu_toggledebug'] = 'Toggle Debug';
 $_gmsg['menu_tools'] = 'Tools';
 $_gmsg['menu_tp'] = 'VHost Templates';
@@ -35,11 +40,6 @@ $_gmsg['menu_versionmgr'] = 'Version Manager';
 $_gmsg['menu_vh'] = 'Virtual Hosts';
 $_gmsg['menu_vh_'] = 'Virtual Host';
 $_gmsg['menu_webadmin'] = 'WebAdmin Settings';
-$_gmsg['menu_devgroup'] = 'Developer Mailing List';
-$_gmsg['menu_releaselog'] = 'Release Log';
-$_gmsg['menu_forum'] = 'Forum';
-$_gmsg['menu_slack'] = 'Slack';
-$_gmsg['menu_cloudimage'] = 'Cloud Images';
 
 
 $_gmsg['tab_addons'] = 'Add-ons';
@@ -83,13 +83,15 @@ $_gmsg['note_collapsemenu'] = 'Collapse Menu';
 $_gmsg['note_configmodified'] = 'Configuration has been modified. To apply changes, please perform a graceful restart.';
 $_gmsg['note_confirm_delete'] = 'Are you sure you want to delete this entry? This will be permanently removed from the configuration file.';
 $_gmsg['note_confirm_instantiate'] = 'Are you sure you want to instantiate this virtual host? This will create a dedicated configuration file for this virtual host.';
+$_gmsg['note_confirm_logout'] = 'Logout';
 $_gmsg['note_copyrightreserved'] = 'All Rights Reserved.';
-$_gmsg['note_curver'] = 'Current Version';
 $_gmsg['note_curbranch'] = 'current branch';
+$_gmsg['note_curver'] = 'Current Version';
 $_gmsg['note_dataretrievedat'] = 'Data retrieved at';
 $_gmsg['note_entfeature'] = 'This feature is available in Enterprise Edition';
 $_gmsg['note_example'] = 'Example';
 $_gmsg['note_fullscreen'] = 'Full Screen';
+$_gmsg['note_home'] = 'Home';
 $_gmsg['note_inputerr'] = 'Input error detected. Please resolve the error(s).';
 $_gmsg['note_loadavg'] = 'System Load Avg';
 $_gmsg['note_logout'] = 'You can improve your security further after logging out by closing this opened browser';
@@ -113,6 +115,8 @@ $_gmsg['err_invalidpath'] = 'Invalid path';
 $_gmsg['err_invalidvalat'] = 'Invalid value at';
 $_gmsg['err_loggedoff'] = 'You have logged off.';
 $_gmsg['err_login'] = 'Invalid credentials.';
+$_gmsg['err_menuanchornotexist'] = 'Error - menu anchor does not exist';
+$_gmsg['err_page_404'] = 'Error 404! Page not found.';
 $_gmsg['err_parentdirnotexist'] = 'Parent directory does not exist';
 $_gmsg['err_requireabspath'] = 'Require absolute path';
 $_gmsg['err_sessiontimeout'] = 'Your session has timed out.';
@@ -177,6 +181,10 @@ $_gmsg['l_binpath'] = 'Binary Path';
 $_gmsg['l_blockbadreq'] = 'Block Bad Request';
 $_gmsg['l_botWhiteList'] = 'Bot White List';
 $_gmsg['l_brcompress'] = 'Brotli Compression';
+$_gmsg['l_brcompresslevel'] = 'Brotli Compression Level (Dynamic Content)';
+$_gmsg['l_brstaticcompresslevel'] = 'Brotli Compression Level (Static File)';
+$_gmsg['l_bubblewrap'] = 'Bubblewrap Container';
+$_gmsg['l_bubblewrapcmd'] = 'Bubblewrap Command';
 $_gmsg['l_byteslog'] = 'Bytes log';
 $_gmsg['l_cacertfile'] = 'CA Certificate File';
 $_gmsg['l_cacertpath'] = 'CA Certificate Path';
@@ -237,7 +245,6 @@ $_gmsg['l_docroot'] = 'Document Root';
 $_gmsg['l_domain'] = 'Domain Name';
 $_gmsg['l_domains'] = 'Domains';
 $_gmsg['l_dynreqpersec'] = 'Dynamic Requests/second';
-$_gmsg['l_brcompresslevel'] = 'Brotli Compression Level (Dynamic Content)';
 $_gmsg['l_enablecache'] = 'Enable Cache';
 $_gmsg['l_enablecensorship'] = 'Enable Request Filtering';
 $_gmsg['l_enablechroot'] = 'Enable chroot';
@@ -247,7 +254,6 @@ $_gmsg['l_enabled'] = 'Enabled';
 $_gmsg['l_enabledhe'] = 'Enable DH Key Exchange';
 $_gmsg['l_enabledyngzipcompress'] = 'Enable GZIP Dynamic Compression';
 $_gmsg['l_enableecdhe'] = 'Enable ECDH Key Exchange';
-$_gmsg['l_enablequic'] = 'Enable QUIC';
 $_gmsg['l_enableexpires'] = 'Enable Expires';
 $_gmsg['l_enablegzip'] = 'Enable GZIP Compression';
 $_gmsg['l_enableh2c'] = 'Enable HTTP/2 Over Cleartext TCP';
@@ -256,6 +262,7 @@ $_gmsg['l_enablehotlinkctrl'] = 'Enable Hotlink Protection';
 $_gmsg['l_enableipgeo'] = 'Enable GeoLocation Lookup';
 $_gmsg['l_enablelve'] = 'Cloud Linux';
 $_gmsg['l_enableprivatecache'] = 'Enable Private Cache';
+$_gmsg['l_enablequic'] = 'Enable QUIC';
 $_gmsg['l_enablerailshosting'] = 'Enable Shared Hosting';
 $_gmsg['l_enablerewrite'] = 'Enable Rewrite';
 $_gmsg['l_enablescript'] = 'Enable Scripts/ExtApps';
@@ -303,12 +310,13 @@ $_gmsg['l_groupdblocation'] = 'Group DB Location';
 $_gmsg['l_groupdbmaxcachesize'] = 'Group DB Max Cache Size';
 $_gmsg['l_groupname'] = 'Group Name';
 $_gmsg['l_groups'] = 'Groups';
-$_gmsg['l_gzipbr'] = 'GZIP/Brotli Compression';
 $_gmsg['l_gzipautoupdatestatic'] = 'Auto Update Static File';
+$_gmsg['l_gzipbr'] = 'GZIP/Brotli Compression';
 $_gmsg['l_gzipcachedir'] = 'Static Cache Directory';
 $_gmsg['l_gzipcompresslevel'] = 'GZIP Compression Level (Dynamic Content)';
 $_gmsg['l_gzipmaxfilesize'] = 'Max Static File Size (bytes)';
 $_gmsg['l_gzipminfilesize'] = 'Min Static File Size (bytes)';
+$_gmsg['l_gzipstaticcompresslevel'] = 'GZIP Compression Level (Static File)';
 $_gmsg['l_handlername'] = 'Handler Name';
 $_gmsg['l_handlertype'] = 'Handler Type';
 $_gmsg['l_hardlimit'] = 'Connection Hard Limit';
@@ -413,6 +421,19 @@ $_gmsg['l_process'] = 'Process';
 $_gmsg['l_prochardlimit'] = 'Process Hard Limit';
 $_gmsg['l_procsoftlimit'] = 'Process Soft Limit';
 $_gmsg['l_protocolver'] = 'Protocol Version';
+$_gmsg['l_quic'] = 'QUIC';
+$_gmsg['l_quicbaseplpmtu'] = 'PLPMTU Base Value';
+$_gmsg['l_quiccfcw'] = 'Connection Flow Control Window';
+$_gmsg['l_quicenabledplpmtud'] = 'Enable DPLPMTUD';
+$_gmsg['l_quichandshaketimeout'] = 'Handshake Timeout (secs)';
+$_gmsg['l_quicidletimeout'] = 'Idle Timeout (secs)';
+$_gmsg['l_quicmaxcfcw'] = 'Max Connection Flow Control Window';
+$_gmsg['l_quicmaxplpmtu'] = 'PLPMTU Max Value';
+$_gmsg['l_quicmaxsfcw'] = 'Max Stream Flow Control Window';
+$_gmsg['l_quicmaxstreams'] = 'Max Concurrent Streams Per Connection';
+$_gmsg['l_quicsfcw'] = 'Stream Flow Control Window';
+$_gmsg['l_quicshmdir'] = 'QUIC SHM Directory';
+$_gmsg['l_quicversions'] = 'QUIC Versions';
 $_gmsg['l_railsapplimit'] = 'Max Apps per Account';
 $_gmsg['l_railshosting'] = 'Rack/Rails Shared Hosting';
 $_gmsg['l_railssettings'] = 'Rack/Rails Default Settings';
@@ -489,8 +510,6 @@ $_gmsg['l_sslStrongDhKey'] = 'SSL Strong DH Key';
 $_gmsg['l_sslprotocol'] = 'SSL Protocol';
 $_gmsg['l_startupfile'] = 'Startup File';
 $_gmsg['l_statDir'] = 'Statistics Output Directory';
-$_gmsg['l_gzipstaticcompresslevel'] = 'GZIP Compression Level (Static File)';
-$_gmsg['l_brstaticcompresslevel'] = 'Brotli Compression Level (Static File)';
 $_gmsg['l_staticreqpersec'] = 'Static Requests/second';
 $_gmsg['l_statuscode'] = 'Status Code';
 $_gmsg['l_storagepath'] = 'Storage Path';
@@ -552,16 +571,6 @@ $_gmsg['l_workers'] = 'Workers';
 $_gmsg['l_workingdir'] = 'Working Directory';
 $_gmsg['l_wsgibin'] = 'WSGI Path';
 $_gmsg['l_wsgisettings'] = 'Python WSGI Default Settings';
-$_gmsg['l_quic'] = 'QUIC';
-$_gmsg['l_quicshmdir'] = 'QUIC SHM Directory';
-$_gmsg['l_quicversions'] = 'QUIC Versions';
-$_gmsg['l_quiccfcw'] = 'Connection Flow Control Window';
-$_gmsg['l_quicmaxcfcw'] = 'Max Connection Flow Control Window';
-$_gmsg['l_quicsfcw'] = 'Stream Flow Control Window';
-$_gmsg['l_quicmaxsfcw'] = 'Max Stream Flow Control Window';
-$_gmsg['l_quicmaxstreams'] = 'Max Concurrent Streams Per Connection';
-$_gmsg['l_quichandshaketimeout'] = 'Handshake Timeout (secs)';
-$_gmsg['l_quicidletimeout'] = 'Idle Timeout (secs)';
 
 
 $_gmsg['o_cagefswithoutsuexec'] = 'CageFS without suEXEC';
@@ -589,8 +598,8 @@ $_gmsg['o_noabort'] = 'No Abort';
 $_gmsg['o_nofornph'] = 'No for Non-Parsed-Header (NPH)';
 $_gmsg['o_none'] = 'None';
 $_gmsg['o_notset'] = 'Not Set';
-$_gmsg['o_on'] = 'On';
 $_gmsg['o_off'] = 'Off';
+$_gmsg['o_on'] = 'On';
 $_gmsg['o_overridecpanelrestartscript'] = 'Override cPanel restart HTTPD script';
 $_gmsg['o_ownlogfile'] = 'Own Log File';
 $_gmsg['o_sameasserver'] = 'Same as Server';
@@ -599,6 +608,7 @@ $_gmsg['o_showver'] = 'Show Version';
 $_gmsg['o_size'] = 'Size';
 $_gmsg['o_thrucgidaemon'] = 'Yes (Through CGI Daemon)';
 $_gmsg['o_trustediponly'] = 'Trusted IP Only';
+$_gmsg['o_use_last_ip_for elb'] = 'Use Last IP (for AWS ELB)';
 $_gmsg['o_useapachebinwrapper'] = 'Use Apache binary wrapper';
 $_gmsg['o_userhomedironly'] = 'User\'s Home Directory Only';
 $_gmsg['o_vhroot'] = 'Virtual Host Root';
@@ -614,7 +624,7 @@ $_gmsg['parse_defaultmimetype'] = 'MIME_type like text/html';
 $_gmsg['parse_env'] = 'PROPERTY=VALUE';
 $_gmsg['parse_expiresByType'] = 'MIME_type=A|Mseconds, MIME type can be like */*, text/*, text/html';
 $_gmsg['parse_expiresdefault'] = '[A|M]###, A means client access time, M means file modified time, ### is number of seconds';
-$_gmsg['parse_forcemimetype'] = 'MIME_type like text/html, or put \\\"NONE\\\" to disable inherited Force Type.';
+$_gmsg['parse_forcemimetype'] = 'MIME_type like text/html, or put "NONE" to disable inherited Force Type.';
 $_gmsg['parse_geodbenv'] = 'Variable_Name mapped_DB_data';
 $_gmsg['parse_mimetype'] = 'like text/html';
 $_gmsg['parse_recaptchakey'] = 'key string assigned from your google reCAPTCHA account';
@@ -737,7 +747,7 @@ $_gmsg['buildphp_mainstatus'] = 'Main Status';
 $_gmsg['buildphp_manualrunnotice'] = '<p>For security reasons, please log in to your server and run the pre-generated script from shell.
 	You can monitor the progress from this screen.</p>
 	<p>If build successfully, please update php.ini accordingly if needed. To apply changes, please do a graceful restart.</p>
-	<p>If it stops due to errors, it may caused by missing packages, after you install it, rerun the same command and this page will show the updated log. For more information regarding LSPHP, please visit <a href=\"https://www.litespeedtech.com/support/wiki/doku.php/litespeed_wiki:php\" rel=\"noopener noreferrer\" target=\"_blank\">LiteSpeed wiki</a>.</p>
+	<p>If it stops due to errors, it may caused by missing packages, after you install it, rerun the same command and this page will show the updated log. For more information regarding LSPHP, please visit <a href="https://www.litespeedtech.com/support/wiki/doku.php/litespeed_wiki:php" rel="noopener noreferrer" target="_blank">LiteSpeed wiki</a>.</p>
 	<p>If you log in as root, you can directly run the command: <br><code>%%manual_script%%</code></p>
 	<p>If you log in as a user who has sudo permission, you can run the command with sudo and input root password after prompt.
 	<code>sudo %%manual_script%%</code></p>';
@@ -769,5 +779,3 @@ If you do not recognize the IP address, please follow below recommended ways to
 2. change the listener port from default value 7080;
 3. do not use simple password;
 4. use https for admin console.';
-
-
